@@ -21,10 +21,10 @@
 
 from __future__ import print_function
 import datetime
-from opsramp.base import ApiWrapper
+from opsramp.api import ORapi
 
 
-class Clients(ApiWrapper):
+class Clients(ORapi):
     def __init__(self, parent):
         super(Clients, self).__init__(parent.api, 'clients')
 
@@ -32,10 +32,14 @@ class Clients(ApiWrapper):
         return self.api.get(suffix)
 
     def search(self, query_string=''):
-        suffix = 'search'
-        if query_string:
-            suffix += '?queryString=' + query_string
-        return self.api.get(suffix)
+        # For historical reasons the caller is allowed to omit the
+        # queryString prefix, so add it if necessary.
+        key = 'queryString='
+        if query_string and key not in query_string:
+            query_string = key + query_string
+        return super(Clients, self).search(
+            pattern=query_string
+        )
 
     def create(self, definition):
         assert 'name' in definition
