@@ -26,7 +26,7 @@ from opsramp.integrations import Instances
 
 class InstancesTest(unittest.TestCase):
     def setUp(self):
-        fake_url = 'http://api.example.com'
+        fake_url = 'mock://api.example.com'
         fake_token = 'unit-test-fake-token'
         self.ormp = opsramp.binding.Opsramp(fake_url, fake_token)
 
@@ -72,7 +72,7 @@ class InstancesTest(unittest.TestCase):
         thisid = 123456
         expected = {'id': thisid}
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('%s/configFile/kubernetes' % thisid)
+            url = group.api.compute_url('%s/configFile/Kubernetes' % thisid)
             m.get(url, json=expected, complete_qs=True)
             actual = group.get_kubernetes_configuration(uuid=thisid)
             assert actual == expected
